==> mongodb-5.0.30.gh.tar.gz: mongo-r5.0.30/src/mongo/s/query/router_stage_mock.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <boost/optional.hpp>
#include <queue>

#include "mongo/s/query/cluster_query_result.h"
#include "mongo/s/query/router_exec_stage.h"

namespace mongo {

/**
 * Initialized by adding results to its results queue, it then passes through the results in its
 * queue until the queue is empty.
 */
class RouterStageMock final : public RouterExecStage {
public:
    RouterStageMock(OperationContext* opCtx) : RouterExecStage(opCtx) {}
    ~RouterStageMock() final {}

    StatusWith<ClusterQueryResult> next(ExecContext) final;

    void kill(OperationContext* opCtx) final;

    bool remotesExhausted() final;

    /**
     * Queues a BSONObj to be returned.
     */
    void queueResult(const ClusterQueryResult& result);

    /**
     * Queues an error response.
     */
    void queueError(Status status);

    /**
     * Queues an explicit boost::none response. The mock stage will also return boost::none
     * automatically after emptying the queue of responses.
     */
    void queueEOF();

    /**
     * Explicitly marks the remote cursors as all exhausted.
     */
    void markRemotesExhausted();

    /**
     * Gets the timeout for awaitData, or an error if none was set.
     */
    StatusWith<Milliseconds> getAwaitDataTimeout();

protected:
    Status doSetAwaitDataTimeout(Milliseconds awaitDataTimeout) final;

private:
    std::queue<StatusWith<ClusterQueryResult>> _resultsQueue;
    bool _remotesExhausted = false;
    boost::optional<Milliseconds> _awaitDataTimeout;
};

}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/s/query/router_stage_mock.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <boost/move/utility_core.hpp>
#include <boost/optional.hpp>
#include <boost/optional/optional.hpp>
#include <queue>

#include "mongo/base/status.h"
#include "mongo/base/status_with.h"
#include "mongo/s/query/cluster_query_result.h"
#include "mongo/s/query/router_exec_stage.h"
#include "mongo/util/duration.h"

namespace mongo {

/**
 * Initialized by adding results to its results queue, it then passes through the results in its
 * queue until the queue is empty.
 */
class RouterStageMock final : public RouterExecStage {
public:
    RouterStageMock(OperationContext* opCtx) : RouterExecStage(opCtx) {}
    ~RouterStageMock() final {}

    StatusWith<ClusterQueryResult> next() final;

    void kill(OperationContext* opCtx) final;

    bool remotesExhausted() final;

    /**
     * Queues a BSONObj to be returned.
     */
    void queueResult(const ClusterQueryResult& result);

    /**
     * Queues an error response.
     */
    void queueError(Status status);

    /**
     * Queues an explicit boost::none response. The mock stage will also return boost::none
     * automatically after emptying the queue of responses.
     */
    void queueEOF();

    /**
     * Explicitly marks the remote cursors as all exhausted.
     */
    void markRemotesExhausted();

    /**
     * Gets the timeout for awaitData, or an error if none was set.
     */
    StatusWith<Milliseconds> getAwaitDataTimeout();

protected:
    Status doSetAwaitDataTimeout(Milliseconds awaitDataTimeout) final;

private:
    std::queue<StatusWith<ClusterQueryResult>> _resultsQueue;
    bool _remotesExhausted = false;
    boost::optional<Milliseconds> _awaitDataTimeout;
};

}  // namespace mongo
